==> Evergreen-ILS-3.14.7.tar.gz: Evergreen-ILS-3.14.7/Open-ILS/web/js/dojo/openils/actor/nls/fr-ca/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "DIFFUSION",
    ":DELETE_ADDRESS": "Supprimer l'adresse ${0}?",
    ":NEED_ADDRESS": "Une adresse est requise lors de l'inscription.",
    ":DUPE_PATRON_NAME": "Trouv\u00e9 ${0} client(s) avec la m\u00eame nom",
    ":DUPE_PATRON_EMAIL": "Trouv\u00e9 ${0} client(s) avec la m\u00eame courriel",
    ":DUPE_PATRON_IDENT": "Trouv\u00e9 ${0} client(s) avec la m\u00eame identification",
    ":DUPE_PATRON_PHONE": "Trouv\u00e9 ${0} client(s) avec la m\u00eame num\u00e9ro de t\u00e9l\u00e9phone",
    ":DUPE_PATRON_ADDR": "Trouv\u00e9 ${0} client(s) avec la m\u00eame adresse",
    ":REPLACED_ADDRESS": "Replaces address ${0}<br/> ${1} ${2}<br/> ${3}, ${4} ${5}",
    ":INVALID_FORM": "Formulaire n'est pas valide. S'il vous pla\u00eet modifier et essayez \u00e0 nouveau.",
    ":EXAMPLE": "Exemple: ",
    ":REPLACE_BARCODE": "Remplacer le code \u00e0 barres",
    ":BARCODE_IN_USE": "Le code \u00e0 barres est d\u00e9j\u00e0 utilis\u00e9",
    ":SEE_ALL": "Voir tout",
    ":DUPE_USERNAME": "Nom d\u2019utilisateur d\u00e9j\u00e0 utilis\u00e9",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "V\u00e9rifier le mot de passe",
    ":PARENT_OR_GUARDIAN": "Parent/tuteur",
    ":USER_SETTINGS": "Param\u00e8tres utilisateur",
    ":ADDRESS_HEADER": "Adresse",
    ":ADDRESS_MAILING": "Envoi",
    ":ADDRESS_BILLING": "Facturation",
    ":ADDRESS_PENDING": "Il s\u2019agit d\u2019une adresse en suspens : ",
    ":ADDRESS_APPROVE": "Adresse approuv\u00e9e",
    ":ADDRESS_OWNED": "Cette adresse appartient \u00e0 un autre utilisateur : ",
    ":ADDRESS_NEW": "Nouvelle adresse",
    ":STAT_CATS": "Cat\u00e9gories statistiques",
    ":SAVE": "Enregistrer",
    ":SAVE_CLONE": "Sauvegarder &amp; Cloner",
    ":SHOW_REQUIRED": "Montrer seulement les champs obligatoires",
    ":SHOW_SUGGESTED": "Montrer les champs sugg\u00e9r\u00e9s",
    ":SHOW_ALL": "Montrer tous les champs",
    ":ALL_CARDS_BARCODE": "Code-barres",
    ":ALL_CARDS_ACTIVE": "Actif",
    ":ALL_CARDS_PRIMARY": "Principal",
    ":ALL_CARDS_CLOSE": "Fermer",
    ":ALL_CARDS_APPLY": "Appliquer les modifications",
    ":INVALIDATE": "Invalider",
    ":HOLD_NOTIFY_PHONE": "T\u00e9l\u00e9phone\u00a0: ",
    ":HOLD_NOTIFY_EMAIL": "Adresse \u00e9lectronique\u00a0: ",
    ":HOLD_NOTIFY_SMS": "SMS\u00a0: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}

==> Evergreen-ILS-3.16.2.tar.gz: Evergreen-ILS-3.16.2/Open-ILS/web/js/dojo/openils/actor/nls/fr-ca/register.js <==
{
    ":DEFAULT_ADDRESS_TYPE": "DIFFUSION",
    ":DELETE_ADDRESS": "Supprimer l'adresse ${0}?",
    ":NEED_ADDRESS": "Une adresse est requise lors de l'inscription.",
    ":DUPE_PATRON_NAME": "Trouv\u00e9 ${0} client(s) avec la m\u00eame nom",
    ":DUPE_PATRON_EMAIL": "Trouv\u00e9 ${0} client(s) avec la m\u00eame courriel",
    ":DUPE_PATRON_IDENT": "Trouv\u00e9 ${0} client(s) avec la m\u00eame identification",
    ":DUPE_PATRON_PHONE": "Trouv\u00e9 ${0} client(s) avec la m\u00eame num\u00e9ro de t\u00e9l\u00e9phone",
    ":DUPE_PATRON_ADDR": "Trouv\u00e9 ${0} client(s) avec la m\u00eame adresse",
    ":REPLACED_ADDRESS": "<div>Remplace l'adresse <b>${0}</b><br/> ${1} ${2}<br/> ${3}, ${4} ${5}</div>",
    ":INVALID_FORM": "Formulaire n'est pas valide. S'il vous pla\u00eet modifier et essayez \u00e0 nouveau.",
    ":EXAMPLE": "Exemple: ",
    ":REPLACE_BARCODE": "Remplacer le code \u00e0 barres",
    ":BARCODE_IN_USE": "Le code \u00e0 barres est d\u00e9j\u00e0 utilis\u00e9",
    ":SEE_ALL": "Voir tout",
    ":DUPE_USERNAME": "Nom d\u2019utilisateur d\u00e9j\u00e0 utilis\u00e9",
    ":RESET_PASSWORD": "Generate Password",
    ":VERIFY_PASSWORD": "V\u00e9rifier le mot de passe",
    ":PARENT_OR_GUARDIAN": "Parent/tuteur",
    ":PARENT_OR_GUARDIAN_EMAIL": "Parent/Guardian Email",
    ":USER_SETTINGS": "Param\u00e8tres utilisateur",
    ":ADDRESS_HEADER": "Adresse",
    ":ADDRESS_MAILING": "Envoi",
    ":ADDRESS_BILLING": "Facturation",
    ":ADDRESS_PENDING": "Il s\u2019agit d\u2019une adresse en suspens : ",
    ":ADDRESS_APPROVE": "Adresse approuv\u00e9e",
    ":ADDRESS_OWNED": "Cette adresse appartient \u00e0 un autre utilisateur : ",
    ":ADDRESS_NEW": "Nouvelle adresse",
    ":STAT_CATS": "Cat\u00e9gories statistiques",
    ":SAVE": "Enregistrer",
    ":SAVE_CLONE": "Sauvegarder &amp; Cloner",
    ":SHOW_REQUIRED": "Montrer seulement les champs obligatoires",
    ":SHOW_SUGGESTED": "Montrer les champs sugg\u00e9r\u00e9s",
    ":SHOW_ALL": "Montrer tous les champs",
    ":ALL_CARDS_BARCODE": "Code-barres",
    ":ALL_CARDS_ACTIVE": "Actif",
    ":ALL_CARDS_PRIMARY": "Principal",
    ":ALL_CARDS_CLOSE": "Fermer",
    ":ALL_CARDS_APPLY": "Appliquer les modifications",
    ":INVALIDATE": "Invalider",
    ":HOLD_NOTIFY_PHONE": "T\u00e9l\u00e9phone\u00a0: ",
    ":HOLD_NOTIFY_EMAIL": "Adresse \u00e9lectronique\u00a0: ",
    ":HOLD_NOTIFY_SMS": "SMS\u00a0: ",
    ":REQUESTING_USER": "Account requested by ${0} ${1}",
    ":UPDATE_EXPIRE_DATE": "Update Expire Date",
    ":DELETE": "Delete",
    ":ADD": "Add",
    ":SECONDARY_GROUP_NOT_ALLOWED": "You do not have permission to add this group.",
    ":SECONDARY_GROUP_IS_PROFILE": "That is already the primary profile group for this patron.",
    ":SECONDARY_GROUP_EXISTS": "This group is on the list already.",
    ":SECONDARY_GROUP_ERROR": "Error saving secondary groups."
}
